## Intent

## Documentation

Documentation for SMQTK is maintained at
[ReadtheDocs](https://smqtk.readthedocs.org), including
[build instructions](https://smqtk.readthedocs.io/en/latest/installation.html)
and [examples](https://smqtk.readthedocs.org/en/latest/examples/overview.html).

Alternatively, you can build the sphinx documentation locally for the most
up-to-date reference (see also: [Building the Documentation](
https://smqtk.readthedocs.io/en/latest/installation.html#building-the-documentation)):
```bash
# Navigate to the documentation root.
cd docs
# Install dependencies and build Sphinx docs.
pip install -r readthedocs-reqs.txt
make html
# Open in your favorite browser!
firefox _build/html/index.html
```
